@@ -9,7 +9,7 @@ https://raw.github.com/bengillies/chrjs.store/master/dist/chrjs-store-latest.js
  *
  * Dependencies: chrjs library, jQuery, TiddlySpace
  *
- * Version: 0.4.2
+ * Version: 0.4.3
  *
  * created by Ben Gillies
  * Chrjs-Store is distributed under a BSD License
@@ -958,7 +958,7 @@ define('localStore',['cache'], function(cache) {
 		var list = function() {
 			var results = [];
 			$.each(store, function(key, tiddler) {
-				results.push(tiddler);
+				results.push(makeCopy(tiddler));
 			});
 			return results;
 		}
@@ -1232,7 +1232,7 @@ return function(tiddlerCallback, getCached, defaultContainers) {
 				});
 				removeDeleted(container, result);
 				if (callback) {
-					callback.apply(self, [result]);
+					callback.call(self, filter(self, result));
 				}
 			}, function(xhr, err, errMsg) {
 				callback(null, {
@@ -1355,7 +1355,7 @@ return function(tiddlerCallback, getCached, defaultContainers) {
 					return;
 				}
 				tiddler.put(function(response) {
-					if (isEqual(tiddler, modified.get(tiddler))) {
+					if (isEqual(preSave, modified.get(tiddler))) {
 						modified.remove(tiddler);
 					}
 					replace(store, response);
@@ -1364,7 +1364,7 @@ return function(tiddlerCallback, getCached, defaultContainers) {
 					var currModified = modified.get(tiddler);
 					if (!currModified || (!isEqual(preSave, tiddler) &&
 							isEqual(preSave, currModified))) {
-						// there was an error, so put it back (if it hasn't already been replaced)
+						// put it back (if it hasn't already been replaced)
 						replace(modified, tiddler);
 					}
 					callback(null, {
@@ -1447,14 +1447,14 @@ return function(tiddlerCallback, getCached, defaultContainers) {
 	// callback fires when the search returns.
 	// query is a string appended to the url as /search?q=<query>
 	self.search = function(query, callback) {
-		getDefaults(function(c) {
+		self.getDefaults(function(c) {
 			var searchObj = new tiddlyweb.Search(query, c.pullFrom.host);
 			searchObj.get(function(tiddlers) {
 				$.each(tiddlers, function(i, tiddler) {
 					store.set(tiddler);
 				});
 
-				callback(tiddlers);
+				callback(filter(self, tiddlers));
 			}, function(xhr, err, errMsg) {
 				callback(null, {
 					name: 'SearchError',
